@@ -2,10 +2,15 @@ import sys
 from dataclasses import dataclass
 from pathlib import Path
 from typing import Set
+from textwrap import dedent
 
 import libcst as cst
 from libcst.metadata import QualifiedNameProvider, ParentNodeProvider
 
+from rich.padding import Padding
+
+MIN_NUM_POINTERS = 2
+
 
 class MethodQualNamesCollector(cst.CSTVisitor):
     METADATA_DEPENDENCIES = (QualifiedNameProvider, ParentNodeProvider)
@@ -65,3 +70,39 @@ class FuncFinder:
 
             for fun_name in self.get_methods_qual_names(tree):
                 yield ".".join(abs_import + (fun_name,))
+
+@dataclass
+class FuncResult:
+    name: str
+    num_pointers: int
+    is_pass: bool
+
+def make_report(func_results: list[FuncResult]):
+
+        def report_line(func_result: FuncResult):
+
+            if func_result.is_pass:
+                color = "green"
+            elif func_result.num_pointers > 0:
+                color = "blue"
+            else:
+                color = "red"
+
+            test_count_str = f"{func_result.num_pointers: <2}"
+            return f"[{color}]{test_count_str:·<5}[/{color}] {func_result.name}"
+
+        report_lines = "\n".join([
+            report_line(func_result)
+            for func_result
+            in func_results
+        ])
+
+        report = dedent(
+            f"""
+        [bold]List of functions in project and the number of tests for them[/bold]
+
+        \n{report_lines}
+        """
+        )
+
+        return Padding(report, (2, 4), expand=False)
